From: Evan Hunt
Date: Sat, 29 Oct 2022 21:22:56 +0000 (-0700)
Subject: remove isc_task completely
X-Git-Tag: v9.19.11~51^2
X-Git-Url: http://git.ipfire.org/gitweb.cgi?a=commitdiff_plain;h=a52b17d39b7c535b7c4182eb6786a7574b148b72;p=thirdparty%2Fbind9.git
remove isc_task completely
as there is no further use of isc_task in BIND, this commit removes
it, along with isc_taskmgr, isc_event, and all other related types.
functions that accepted taskmgr as a parameter have been cleaned up.
as a result of this change, some functions can no longer fail, so
they've been changed to type void, and their callers have been
updated accordingly.
the tasks table has been removed from the statistics channel and
the stats version has been updated. dns_dyndbctx has been changed
to reference the loopmgr instead of taskmgr, and DNS_DYNDB_VERSION
has been udpated as well.
---
diff --git a/bin/check/named-checkzone.c b/bin/check/named-checkzone.c
index a5d61836177..795624651ad 100644
--- a/bin/check/named-checkzone.c
+++ b/bin/check/named-checkzone.c
@@ -26,7 +26,6 @@
#include
#include
#include
-#include
#include
#include
diff --git a/bin/delv/delv.c b/bin/delv/delv.c
index 82bdef98458..7fa6eb86794 100644
--- a/bin/delv/delv.c
+++ b/bin/delv/delv.c
@@ -38,7 +38,6 @@
#include
#include
#include
-#include
#include
#include
#include
@@ -83,7 +82,6 @@ static isc_log_t *lctx = NULL;
/* Managers */
static isc_nm_t *netmgr = NULL;
static isc_loopmgr_t *loopmgr = NULL;
-static isc_taskmgr_t *taskmgr = NULL;
/* TLS */
static isc_tlsctx_cache_t *tlsctx_client_cache = NULL;
@@ -1813,7 +1811,7 @@ main(int argc, char *argv[]) {
argc--;
argv++;
- isc_managers_create(&mctx, 1, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_create(&mctx, 1, &loopmgr, &netmgr);
result = dst_lib_init(mctx, NULL);
if (result != ISC_R_SUCCESS) {
@@ -1871,7 +1869,7 @@ cleanup:
dst_lib_destroy();
- isc_managers_destroy(&mctx, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_destroy(&mctx, &loopmgr, &netmgr);
return (0);
}
diff --git a/bin/dig/dig.c b/bin/dig/dig.c
index 0d1814cda50..06940123dc0 100644
--- a/bin/dig/dig.c
+++ b/bin/dig/dig.c
@@ -26,7 +26,6 @@
#include
#include
#include
-#include
#include
#include
diff --git a/bin/dig/dighost.c b/bin/dig/dighost.c
index 25c3bdde333..5c73e28522d 100644
--- a/bin/dig/dighost.c
+++ b/bin/dig/dighost.c
@@ -51,7 +51,6 @@
#include
#include
#include
-#include
#include
#include
#include
@@ -104,7 +103,6 @@ unsigned int extrabytes;
isc_mem_t *mctx = NULL;
isc_log_t *lctx = NULL;
isc_nm_t *netmgr = NULL;
-isc_taskmgr_t *taskmgr = NULL;
isc_loopmgr_t *loopmgr = NULL;
isc_loop_t *mainloop = NULL;
isc_sockaddr_t localaddr;
@@ -1369,7 +1367,7 @@ setup_libs(void) {
fatal("can't find either v4 or v6 networking");
}
- isc_managers_create(&mctx, 1, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_create(&mctx, 1, &loopmgr, &netmgr);
isc_log_create(mctx, &lctx, &logconfig);
isc_log_setcontext(lctx);
@@ -4716,7 +4714,7 @@ destroy_libs(void) {
isc_mem_stats(mctx, stderr);
}
- isc_managers_destroy(&mctx, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_destroy(&mctx, &loopmgr, &netmgr);
#if ENABLE_LEAK_DETECTION
isc__tls_setdestroycheck(true);
diff --git a/bin/dig/dighost.h b/bin/dig/dighost.h
index 4c12260338a..5daffbc5002 100644
--- a/bin/dig/dighost.h
+++ b/bin/dig/dighost.h
@@ -263,7 +263,6 @@ extern const dns_name_t *hmacname;
extern unsigned int digestbits;
extern dns_tsigkey_t *tsigkey;
extern bool validated;
-extern isc_taskmgr_t *taskmgr;
extern isc_loopmgr_t *loopmgr;
extern isc_loop_t *mainloop;
extern bool free_now;
diff --git a/bin/dig/host.c b/bin/dig/host.c
index 42b567f0e71..35ef45e8195 100644
--- a/bin/dig/host.c
+++ b/bin/dig/host.c
@@ -24,7 +24,6 @@
#include
#include
#include
-#include
#include
#include
diff --git a/bin/dig/nslookup.c b/bin/dig/nslookup.c
index 7c21225af25..2d5f0b890d4 100644
--- a/bin/dig/nslookup.c
+++ b/bin/dig/nslookup.c
@@ -20,13 +20,11 @@
#include
#include
#include
-#include
#include
#include
#include
#include
#include
-#include
#include
#include
diff --git a/bin/dnssec/dnssec-signzone.c b/bin/dnssec/dnssec-signzone.c
index 215e44ebe08..ac21797bc31 100644
--- a/bin/dnssec/dnssec-signzone.c
+++ b/bin/dnssec/dnssec-signzone.c
@@ -38,7 +38,6 @@
#include
#include
#include
-#include
#include
#include
#include
@@ -56,7 +55,6 @@
#include
#include
#include
-#include
#include
#include
#include
@@ -140,7 +138,6 @@ static const char *directory = NULL, *dsdir = NULL;
static isc_mutex_t namelock, statslock;
static isc_nm_t *netmgr = NULL;
static isc_loopmgr_t *loopmgr = NULL;
-static isc_taskmgr_t *taskmgr = NULL;
static dns_db_t *gdb; /* The database */
static dns_dbversion_t *gversion; /* The database version */
static dns_dbiterator_t *gdbiter; /* The database iterator */
@@ -3636,7 +3633,7 @@ main(int argc, char *argv[]) {
directory = ".";
}
- isc_managers_create(&mctx, nloops, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_create(&mctx, nloops, &loopmgr, &netmgr);
result = dst_lib_init(mctx, engine);
if (result != ISC_R_SUCCESS) {
@@ -4021,7 +4018,7 @@ main(int argc, char *argv[]) {
isc_mem_stats(mctx, stdout);
}
- isc_managers_destroy(&mctx, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_destroy(&mctx, &loopmgr, &netmgr);
if (printstats) {
TIME_NOW(&timer_finish);
diff --git a/bin/dnssec/dnssec-verify.c b/bin/dnssec/dnssec-verify.c
index 9e51547ae73..539b1552753 100644
--- a/bin/dnssec/dnssec-verify.c
+++ b/bin/dnssec/dnssec-verify.c
@@ -20,7 +20,6 @@
#include
#include
#include
-#include
#include
#include
#include
diff --git a/bin/named/bind9.xsl b/bin/named/bind9.xsl
index f86bf871412..91f59440d2b 100644
--- a/bin/named/bind9.xsl
+++ b/bin/named/bind9.xsl
@@ -156,29 +156,6 @@
background-color: #99ddff;
}
- table.tasks {
- border: 1px solid grey;
- width: 500px;
- }
- table.tasks th {
- text-align: center;
- border: 1px solid grey;
- width: 150px;
- }
- table.tasks td {
- text-align: right;
- font-family: monospace;
- }
- table.tasks td:nth-child(2) {
- text-align: center;
- }
- table.tasks td:nth-child(4) {
- text-align: center;
- }
- table.tasks tr:hover{
- background-color: #99ddff;
- }
-
table.netstat {
border: 1px solid grey;
width: 500px;
@@ -327,7 +304,6 @@
Server,
Zones,
Network,
- Tasks,
Memory and
Traffic Size
@@ -931,85 +907,6 @@
-
- Task Manager Configuration
-
-
- | Thread-Model |
-
-
- |
-
-
- | Worker Threads |
-
-
- |
-
-
- | Default Quantum |
-
-
- |
-
-
- | Tasks Running |
-
-
- |
-
-
- | Tasks Ready |
-
-
- |
-
-
-
-
-
- Tasks
-
-
- | ID |
- Name |
- References |
- State |
- Quantum |
- Events |
-
-
-
-
-
- even
- odd
-
-
-
- |
-
- |
-
-
- |
-
-
- |
-
-
- |
-
-
- |
-
-
- |
-
-
-
-
-
Memory Usage Summary
diff --git a/bin/named/control.c b/bin/named/control.c
index 71863587932..47749644b6f 100644
--- a/bin/named/control.c
+++ b/bin/named/control.c
@@ -15,7 +15,6 @@
#include
-#include
#include
#include
#include
diff --git a/bin/named/include/named/globals.h b/bin/named/include/named/globals.h
index ddcd81179ab..40b37143bc1 100644
--- a/bin/named/include/named/globals.h
+++ b/bin/named/include/named/globals.h
@@ -50,7 +50,6 @@
EXTERN isc_mem_t *named_g_mctx INIT(NULL);
EXTERN unsigned int named_g_cpus INIT(0);
EXTERN unsigned int named_g_udpdisp INIT(0);
-EXTERN isc_taskmgr_t *named_g_taskmgr INIT(NULL);
EXTERN isc_loop_t *named_g_mainloop INIT(NULL);
EXTERN isc_loopmgr_t *named_g_loopmgr INIT(NULL);
EXTERN dns_dispatchmgr_t *named_g_dispatchmgr INIT(NULL);
diff --git a/bin/named/include/named/server.h b/bin/named/include/named/server.h
index 57b29d4206b..4d87fc99c18 100644
--- a/bin/named/include/named/server.h
+++ b/bin/named/include/named/server.h
@@ -38,14 +38,6 @@
#include
-#define NAMED_EVENTCLASS ISC_EVENTCLASS(0x4E43)
-#define NAMED_EVENT_RELOAD (NAMED_EVENTCLASS + 0)
-#define NAMED_EVENT_DELZONE (NAMED_EVENTCLASS + 1)
-#define NAMED_EVENT_COMMAND (NAMED_EVENTCLASS + 2)
-#define NAMED_EVENT_TATSEND (NAMED_EVENTCLASS + 3)
-#define NAMED_EVENT_RUN (NAMED_EVENTCLASS + 4)
-#define NAMED_EVENT_SHUTDOWN (NAMED_EVENTCLASS + 5)
-
/*%
* Name server state. Better here than in lots of separate global variables.
*/
@@ -55,8 +47,6 @@ struct named_server {
ns_server_t *sctx;
- isc_task_t *task;
-
char *statsfile; /*%< Statistics file name */
char *dumpfile; /*%< Dump file name */
char *secrootsfile; /*%< Secroots file name */
diff --git a/bin/named/main.c b/bin/named/main.c
index f09f655d235..42b550d3bdf 100644
--- a/bin/named/main.c
+++ b/bin/named/main.c
@@ -38,7 +38,6 @@
#include
#include
#include
-#include
#include
#include
#include
@@ -1026,7 +1025,7 @@ create_managers(void) {
named_g_udpdisp == 1 ? "" : "s");
isc_managers_create(&named_g_mctx, named_g_cpus, &named_g_loopmgr,
- &named_g_netmgr, &named_g_taskmgr);
+ &named_g_netmgr);
isc_nm_maxudp(named_g_netmgr, maxudp);
@@ -1543,8 +1542,7 @@ main(int argc, char *argv[]) {
}
}
- isc_managers_destroy(&named_g_mctx, &named_g_loopmgr, &named_g_netmgr,
- &named_g_taskmgr);
+ isc_managers_destroy(&named_g_mctx, &named_g_loopmgr, &named_g_netmgr);
#if ENABLE_LEAK_DETECTION
isc__tls_setdestroycheck(true);
diff --git a/bin/named/server.c b/bin/named/server.c
index 47713427c83..bf4b3e10c7a 100644
--- a/bin/named/server.c
+++ b/bin/named/server.c
@@ -58,7 +58,6 @@
#include
#include
#include
-#include
#include
#include
@@ -73,7 +72,6 @@
#include
#include
#include
-#include
#include
#include
#include
@@ -216,12 +214,12 @@
} \
} while (0)
-#define CHECKFATAL(op, msg) \
- { \
- result = (op); \
- if (result != ISC_R_SUCCESS) { \
- fatal(server, msg, result); \
- } \
+#define CHECKFATAL(op, msg) \
+ { \
+ result = (op); \
+ if (result != ISC_R_SUCCESS) { \
+ fatal(msg, result); \
+ } \
}
/*%
@@ -404,7 +402,7 @@ const char *empty_zones[] = {
};
noreturn static void
-fatal(named_server_t *server, const char *msg, isc_result_t result);
+fatal(const char *msg, isc_result_t result);
static void
named_server_reload(void *arg);
@@ -9145,16 +9143,7 @@ load_configuration(const char *filename, named_server_t *server,
(void)cfg_map_get(config, "view", &views);
/*
- * Create the views and count all the configured zones in
- * order to correctly size the zone manager's task table.
- * (We only count zones for configured views; the built-in
- * "bind" view can be ignored as it only adds a negligible
- * number of zones.)
- *
- * If we're allowing new zones, we need to be able to find the
- * new zone file and count those as well. So we setup the new
- * zone configuration context, but otherwise view configuration
- * waits until after the zone manager's task list has been sized.
+ * Create the views.
*/
for (element = cfg_list_first(views); element != NULL;
element = cfg_list_next(element))
@@ -9977,10 +9966,8 @@ run_server(void *arg) {
named_server_t *server = (named_server_t *)arg;
dns_geoip_databases_t *geoip = NULL;
- CHECKFATAL(dns_zonemgr_create(named_g_mctx, named_g_loopmgr,
- named_g_taskmgr, named_g_netmgr,
- &server->zonemgr),
- "dns_zonemgr_create");
+ dns_zonemgr_create(named_g_mctx, named_g_loopmgr, named_g_netmgr,
+ &server->zonemgr);
CHECKFATAL(dns_dispatchmgr_create(named_g_mctx, named_g_netmgr,
&named_g_dispatchmgr),
@@ -9994,10 +9981,10 @@ run_server(void *arg) {
geoip = NULL;
#endif /* if defined(HAVE_GEOIP2) */
- CHECKFATAL(ns_interfacemgr_create(
- named_g_mctx, server->sctx, named_g_loopmgr,
- named_g_taskmgr, named_g_netmgr, named_g_dispatchmgr,
- server->task, geoip, true, &server->interfacemgr),
+ CHECKFATAL(ns_interfacemgr_create(named_g_mctx, server->sctx,
+ named_g_loopmgr, named_g_netmgr,
+ named_g_dispatchmgr, geoip, true,
+ &server->interfacemgr),
"creating interface manager");
/*
@@ -10145,8 +10132,6 @@ shutdown_server(void *arg) {
dns_db_detach(&server->in_roothints);
isc_loopmgr_resume(named_g_loopmgr);
-
- isc_task_detach(&server->task);
}
/*%
@@ -10226,16 +10211,6 @@ named_server_create(isc_mem_t *mctx, named_server_t **serverp) {
atomic_init(&server->reload_status, NAMED_RELOAD_IN_PROGRESS);
- /*
- * Setup the server task, which is responsible for coordinating
- * startup and shutdown of the server, as well as all exclusive
- * tasks.
- */
- CHECKFATAL(isc_task_create(named_g_taskmgr, &server->task, 0),
- "creating server task");
- isc_task_setname(server->task, "server", server);
- isc_taskmgr_setexcltask(named_g_taskmgr, server->task);
-
CHECKFATAL(ns_server_create(mctx, get_matching_view, &server->sctx),
"creating server context");
@@ -10355,15 +10330,8 @@ named_server_destroy(named_server_t **serverp) {
}
static void
-fatal(named_server_t *server, const char *msg, isc_result_t result) {
- if (server != NULL && server->task != NULL) {
- /*
- * Prevent races between the OpenSSL on_exit registered
- * function and any other OpenSSL calls from other tasks
- * by requesting exclusive access to the task manager.
- */
- isc_loopmgr_pause(named_g_loopmgr);
- }
+fatal(const char *msg, isc_result_t result) {
+ isc_loopmgr_pause(named_g_loopmgr);
isc_log_write(named_g_lctx, NAMED_LOGCATEGORY_GENERAL,
NAMED_LOGMODULE_SERVER, ISC_LOG_CRITICAL, "%s: %s", msg,
isc_result_totext(result));
@@ -12440,7 +12408,6 @@ named_server_tsigdelete(named_server_t *server, isc_lex_t *lex,
RWUNLOCK(&view->dynamickeys->lock,
isc_rwlocktype_write);
if (result != ISC_R_SUCCESS) {
- isc_task_endexclusive(server->task);
isc_loopmgr_resume(named_g_loopmgr);
return (result);
}
diff --git a/bin/named/statschannel.c b/bin/named/statschannel.c
index aafdecbfbbb..180f75581c3 100644
--- a/bin/named/statschannel.c
+++ b/bin/named/statschannel.c
@@ -77,13 +77,12 @@ struct named_statschannel {
isc_mem_t *mctx;
/*
- * Locked by channel lock: can be referenced and modified by both
- * the server task and the channel task.
+ * Locked by channel lock
*/
isc_mutex_t lock;
dns_acl_t *acl;
- /* Locked by server task */
+ /* Locked by main loop. */
ISC_LINK(struct named_statschannel) link;
};
@@ -1778,7 +1777,6 @@ cleanup:
#define STATS_XML_STATUS 0x00 /* display only common statistics */
#define STATS_XML_SERVER 0x01
#define STATS_XML_ZONES 0x02
-#define STATS_XML_TASKS 0x04
#define STATS_XML_NET 0x08
#define STATS_XML_MEM 0x10
#define STATS_XML_TRAFFIC 0x20
@@ -2334,12 +2332,6 @@ generatexml(named_server_t *server, uint32_t flags, int *buflen,
}
TRY0(xmlTextWriterEndElement(writer)); /* /views */
- if ((flags & STATS_XML_TASKS) != 0) {
- TRY0(xmlTextWriterStartElement(writer, ISC_XMLCHAR "taskmgr"));
- TRY0(isc_taskmgr_renderxml(named_g_taskmgr, writer));
- TRY0(xmlTextWriterEndElement(writer)); /* /taskmgr */
- }
-
if ((flags & STATS_XML_MEM) != 0) {
TRY0(xmlTextWriterStartElement(writer, ISC_XMLCHAR "memory"));
TRY0(isc_mem_renderxml(writer));
@@ -2461,17 +2453,6 @@ render_xml_net(const isc_httpd_t *httpd, const isc_httpdurl_t *urlinfo,
freecb, freecb_args));
}
-static isc_result_t
-render_xml_tasks(const isc_httpd_t *httpd, const isc_httpdurl_t *urlinfo,
- void *arg, unsigned int *retcode, const char **retmsg,
- const char **mimetype, isc_buffer_t *b,
- isc_httpdfree_t **freecb, void **freecb_args) {
- UNUSED(httpd);
- UNUSED(urlinfo);
- return (render_xml(STATS_XML_TASKS, arg, retcode, retmsg, mimetype, b,
- freecb, freecb_args));
-}
-
static isc_result_t
render_xml_mem(const isc_httpd_t *httpd, const isc_httpdurl_t *urlinfo,
void *arg, unsigned int *retcode, const char **retmsg,
@@ -2503,7 +2484,6 @@ render_xml_traffic(const isc_httpd_t *httpd, const isc_httpdurl_t *urlinfo,
#define STATS_JSON_STATUS 0x00 /* display only common statistics */
#define STATS_JSON_SERVER 0x01
#define STATS_JSON_ZONES 0x02
-#define STATS_JSON_TASKS 0x04
#define STATS_JSON_NET 0x08
#define STATS_JSON_MEM 0x10
#define STATS_JSON_TRAFFIC 0x20
@@ -3138,19 +3118,6 @@ generatejson(named_server_t *server, size_t *msglen, const char **msg,
}
}
- if ((flags & STATS_JSON_TASKS) != 0) {
- json_object *tasks = json_object_new_object();
- CHECKMEM(tasks);
-
- result = isc_taskmgr_renderjson(named_g_taskmgr, tasks);
- if (result != ISC_R_SUCCESS) {
- json_object_put(tasks);
- goto cleanup;
- }
-
- json_object_object_add(bindstats, "taskmgr", tasks);
- }
-
if ((flags & STATS_JSON_MEM) != 0) {
json_object *memory = json_object_new_object();
CHECKMEM(memory);
@@ -3403,17 +3370,6 @@ render_json_mem(const isc_httpd_t *httpd, const isc_httpdurl_t *urlinfo,
freecb, freecb_args));
}
-static isc_result_t
-render_json_tasks(const isc_httpd_t *httpd, const isc_httpdurl_t *urlinfo,
- void *arg, unsigned int *retcode, const char **retmsg,
- const char **mimetype, isc_buffer_t *b,
- isc_httpdfree_t **freecb, void **freecb_args) {
- UNUSED(httpd);
- UNUSED(urlinfo);
- return (render_json(STATS_JSON_TASKS, arg, retcode, retmsg, mimetype, b,
- freecb, freecb_args));
-}
-
static isc_result_t
render_json_net(const isc_httpd_t *httpd, const isc_httpdurl_t *urlinfo,
void *arg, unsigned int *retcode, const char **retmsg,
@@ -3611,9 +3567,6 @@ add_listener(named_server_t *server, named_statschannel_t **listenerp,
isc_httpdmgr_addurl(listener->httpdmgr,
"/xml/v" STATS_XML_VERSION_MAJOR "/net", false,
render_xml_net, server);
- isc_httpdmgr_addurl(listener->httpdmgr,
- "/xml/v" STATS_XML_VERSION_MAJOR "/tasks", false,
- render_xml_tasks, server);
isc_httpdmgr_addurl(listener->httpdmgr,
"/xml/v" STATS_XML_VERSION_MAJOR "/mem", false,
render_xml_mem, server);
@@ -3636,9 +3589,6 @@ add_listener(named_server_t *server, named_statschannel_t **listenerp,
isc_httpdmgr_addurl(listener->httpdmgr,
"/json/v" STATS_JSON_VERSION_MAJOR "/zones", false,
render_json_zones, server);
- isc_httpdmgr_addurl(listener->httpdmgr,
- "/json/v" STATS_JSON_VERSION_MAJOR "/tasks", false,
- render_json_tasks, server);
isc_httpdmgr_addurl(listener->httpdmgr,
"/json/v" STATS_JSON_VERSION_MAJOR "/net", false,
render_json_net, server);
diff --git a/bin/nsupdate/nsupdate.c b/bin/nsupdate/nsupdate.c
index 0e81a99532f..58b36619a4e 100644
--- a/bin/nsupdate/nsupdate.c
+++ b/bin/nsupdate/nsupdate.c
@@ -125,7 +125,6 @@ static bool use_win2k_gsstsig = false;
static bool tried_other_gsstsig = false;
static bool local_only = false;
static isc_nm_t *netmgr = NULL;
-static isc_taskmgr_t *taskmgr = NULL;
static isc_loopmgr_t *loopmgr = NULL;
static isc_log_t *glctx = NULL;
static isc_mem_t *gmctx = NULL;
@@ -3443,9 +3442,6 @@ cleanup(void) {
}
#ifdef HAVE_GSSAPI
- /*
- * Cleanup GSSAPI resources after taskmgr has been destroyed.
- */
if (kserver != NULL) {
isc_mem_put(gmctx, kserver, sizeof(isc_sockaddr_t));
kserver = NULL;
@@ -3479,7 +3475,7 @@ cleanup(void) {
}
ddebug("Shutting down managers");
- isc_managers_destroy(&gmctx, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_destroy(&gmctx, &loopmgr, &netmgr);
}
static void
@@ -3526,7 +3522,7 @@ main(int argc, char **argv) {
pre_parse_args(argc, argv);
- isc_managers_create(&gmctx, 1, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_create(&gmctx, 1, &loopmgr, &netmgr);
parse_args(argc, argv);
diff --git a/bin/rndc/rndc.c b/bin/rndc/rndc.c
index 04f6705a2ec..3d226ac03ce 100644
--- a/bin/rndc/rndc.c
+++ b/bin/rndc/rndc.c
@@ -33,7 +33,6 @@
#include
#include
#include
-#include
#include
#include
@@ -59,9 +58,7 @@ const char *progname = NULL;
bool verbose;
static isc_nm_t *netmgr = NULL;
-static isc_taskmgr_t *taskmgr = NULL;
static isc_loopmgr_t *loopmgr = NULL;
-static isc_task_t *rndc_task = NULL;
static const char *admin_conffile = NULL;
static const char *admin_keyfile = NULL;
@@ -307,7 +304,6 @@ rndc_senddone(isc_nmhandle_t *handle, isc_result_t result, void *arg) {
atomic_load_acquire(&recvs) == 0)
{
shuttingdown = true;
- isc_task_detach(&rndc_task);
isc_loopmgr_shutdown(loopmgr);
}
}
@@ -393,7 +389,6 @@ rndc_recvdone(isc_nmhandle_t *handle, isc_result_t result, void *arg) {
atomic_load_acquire(&sends) == 0)
{
shuttingdown = true;
- isc_task_detach(&rndc_task);
isc_loopmgr_shutdown(loopmgr);
}
}
@@ -1025,10 +1020,9 @@ main(int argc, char **argv) {
serial = isc_random32();
- isc_managers_create(&rndc_mctx, 1, &loopmgr, &netmgr, &taskmgr);
- isc_loopmgr_setup(loopmgr, rndc_start, rndc_task);
+ isc_managers_create(&rndc_mctx, 1, &loopmgr, &netmgr);
+ isc_loopmgr_setup(loopmgr, rndc_start, NULL);
- DO("create task", isc_task_create(taskmgr, &rndc_task, 0));
isc_log_create(rndc_mctx, &log, &logconfig);
isc_log_setcontext(log);
isc_log_settag(logconfig, progname);
@@ -1098,7 +1092,7 @@ main(int argc, char **argv) {
isc_mem_stats(rndc_mctx, stderr);
}
- isc_managers_destroy(&rndc_mctx, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_destroy(&rndc_mctx, &loopmgr, &netmgr);
if (failed) {
return (1);
diff --git a/bin/tests/system/dyndb/driver/instance.c b/bin/tests/system/dyndb/driver/instance.c
index 046f9e8ebb9..4ce0d1b31be 100644
--- a/bin/tests/system/dyndb/driver/instance.c
+++ b/bin/tests/system/dyndb/driver/instance.c
@@ -37,7 +37,6 @@
#include "instance.h"
-#include
#include
#include
diff --git a/bin/tests/system/dyndb/driver/zone.c b/bin/tests/system/dyndb/driver/zone.c
index 564ed73d7da..a8d36058d7f 100644
--- a/bin/tests/system/dyndb/driver/zone.c
+++ b/bin/tests/system/dyndb/driver/zone.c
@@ -35,7 +35,6 @@
#include
#include
-#include
#include
#include
diff --git a/bin/tests/system/pipelined/pipequeries.c b/bin/tests/system/pipelined/pipequeries.c
index 7c1fa8ab685..8d8cb453725 100644
--- a/bin/tests/system/pipelined/pipequeries.c
+++ b/bin/tests/system/pipelined/pipequeries.c
@@ -29,11 +29,9 @@
#include
#include
#include
-#include
#include
#include
-#include
#include
#include
#include
@@ -194,7 +192,6 @@ main(int argc, char *argv[]) {
isc_log_t *lctx = NULL;
isc_logconfig_t *lcfg = NULL;
isc_nm_t *netmgr = NULL;
- isc_taskmgr_t *taskmgr = NULL;
dns_dispatchmgr_t *dispatchmgr = NULL;
dns_dispatch_t *dispatchv4 = NULL;
dns_view_t *view = NULL;
@@ -247,7 +244,7 @@ main(int argc, char *argv[]) {
}
isc_sockaddr_fromin(&dstaddr, &inaddr, port);
- isc_managers_create(&mctx, 1, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_create(&mctx, 1, &loopmgr, &netmgr);
isc_log_create(mctx, &lctx, &lcfg);
@@ -277,7 +274,7 @@ main(int argc, char *argv[]) {
isc_log_destroy(&lctx);
- isc_managers_destroy(&mctx, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_destroy(&mctx, &loopmgr, &netmgr);
return (0);
}
diff --git a/bin/tests/system/statistics/tests.sh b/bin/tests/system/statistics/tests.sh
index edfce8b3ebd..0fc1b6b71d9 100644
--- a/bin/tests/system/statistics/tests.sh
+++ b/bin/tests/system/statistics/tests.sh
@@ -215,8 +215,6 @@ if $FEATURETEST --have-libxml2 && "${CURL}" --http1.1 http://10.53.0.3:${EXTRAPO
# grep "Glue cache statistics
" xsltproc.out.${n} >/dev/null || ret=1
grep "View _default" xsltproc.out.${n} >/dev/null || ret=1
grep "Zone example" xsltproc.out.${n} >/dev/null || ret=1
- # grep "Task Manager Configuration
" xsltproc.out.${n} >/dev/null || ret=1
- grep "Tasks
" xsltproc.out.${n} >/dev/null || ret=1
grep "Memory Usage Summary
" xsltproc.out.${n} >/dev/null || ret=1
grep "Memory Contexts
" xsltproc.out.${n} >/dev/null || ret=1
else
diff --git a/bin/tests/system/tkey/keycreate.c b/bin/tests/system/tkey/keycreate.c
index 86e0c4fc674..d4c01d19c02 100644
--- a/bin/tests/system/tkey/keycreate.c
+++ b/bin/tests/system/tkey/keycreate.c
@@ -25,7 +25,6 @@
#include
#include
#include
-#include
#include
#include
@@ -183,7 +182,6 @@ int
main(int argc, char *argv[]) {
char *ourkeyname = NULL;
isc_nm_t *netmgr = NULL;
- isc_taskmgr_t *taskmgr = NULL;
isc_sockaddr_t bind_any;
dns_dispatchmgr_t *dispatchmgr = NULL;
dns_dispatch_t *dispatchv4 = NULL;
@@ -208,7 +206,7 @@ main(int argc, char *argv[]) {
isc_mem_debugging = ISC_MEM_DEBUGRECORD;
- isc_managers_create(&mctx, 1, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_create(&mctx, 1, &loopmgr, &netmgr);
isc_log_create(mctx, &log, &logconfig);
@@ -256,7 +254,7 @@ main(int argc, char *argv[]) {
dst_lib_destroy();
- isc_managers_destroy(&mctx, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_destroy(&mctx, &loopmgr, &netmgr);
return (0);
}
diff --git a/bin/tests/system/tkey/keydelete.c b/bin/tests/system/tkey/keydelete.c
index d6530bb43d0..eb1bef1af18 100644
--- a/bin/tests/system/tkey/keydelete.c
+++ b/bin/tests/system/tkey/keydelete.c
@@ -24,7 +24,6 @@
#include
#include
#include
-#include
#include
#include
@@ -127,7 +126,6 @@ int
main(int argc, char **argv) {
char *keyname = NULL;
isc_nm_t *netmgr = NULL;
- isc_taskmgr_t *taskmgr = NULL;
isc_sockaddr_t bind_any;
dns_dispatchmgr_t *dispatchmgr = NULL;
dns_dispatch_t *dispatchv4 = NULL;
@@ -151,7 +149,7 @@ main(int argc, char **argv) {
port = atoi(argv[2]);
keyname = argv[3];
- isc_managers_create(&mctx, 1, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_create(&mctx, 1, &loopmgr, &netmgr);
isc_log_create(mctx, &log, &logconfig);
@@ -198,7 +196,7 @@ main(int argc, char **argv) {
dst_lib_destroy();
- isc_managers_destroy(&mctx, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_destroy(&mctx, &loopmgr, &netmgr);
return (0);
}
diff --git a/bin/tests/test_client.c b/bin/tests/test_client.c
index eaecb83ef89..872651cd697 100644
--- a/bin/tests/test_client.c
+++ b/bin/tests/test_client.c
@@ -53,7 +53,6 @@ static const char *protocols[] = { "udp", "tcp",
static isc_mem_t *mctx = NULL;
static isc_loopmgr_t *loopmgr = NULL;
static isc_nm_t *netmgr = NULL;
-static isc_taskmgr_t *taskmgr = NULL;
static protocol_t protocol;
static const char *address;
@@ -287,7 +286,7 @@ parse_options(int argc, char **argv) {
static void
setup(void) {
- isc_managers_create(&mctx, workers, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_create(&mctx, workers, &loopmgr, &netmgr);
}
static void
@@ -300,7 +299,7 @@ teardown(void) {
isc_tlsctx_free(&tls_ctx);
}
- isc_managers_destroy(&mctx, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_destroy(&mctx, &loopmgr, &netmgr);
}
static void
diff --git a/bin/tests/test_server.c b/bin/tests/test_server.c
index 05acf8430a5..e0d3bb45ec8 100644
--- a/bin/tests/test_server.c
+++ b/bin/tests/test_server.c
@@ -35,7 +35,6 @@ static const char *protocols[] = { "udp", "tcp", "dot", "https", "http-plain" };
static isc_mem_t *mctx = NULL;
static isc_loopmgr_t *loopmgr = NULL;
static isc_nm_t *netmgr = NULL;
-static isc_taskmgr_t *taskmgr = NULL;
static protocol_t protocol;
static in_port_t port;
@@ -168,7 +167,7 @@ parse_options(int argc, char **argv) {
static void
setup(void) {
- isc_managers_create(&mctx, workers, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_create(&mctx, workers, &loopmgr, &netmgr);
}
static void
@@ -177,7 +176,7 @@ teardown(void) {
isc_tlsctx_free(&tls_ctx);
}
- isc_managers_destroy(&mctx, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_destroy(&mctx, &loopmgr, &netmgr);
}
static void
diff --git a/bin/tools/mdig.c b/bin/tools/mdig.c
index 4e3187dfbae..f519696af42 100644
--- a/bin/tools/mdig.c
+++ b/bin/tools/mdig.c
@@ -34,13 +34,11 @@
#include
#include
#include
-#include
#include
#include
#include
#include
-#include
#include
#include
#include
@@ -2080,7 +2078,6 @@ main(int argc, char *argv[]) {
isc_log_t *lctx = NULL;
isc_logconfig_t *lcfg = NULL;
isc_nm_t *netmgr = NULL;
- isc_taskmgr_t *taskmgr = NULL;
dns_dispatchmgr_t *dispatchmgr = NULL;
dns_dispatch_t *dispatchvx = NULL;
dns_view_t *view = NULL;
@@ -2099,7 +2096,7 @@ main(int argc, char *argv[]) {
preparse_args(argc, argv);
- isc_managers_create(&mctx, 1, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_create(&mctx, 1, &loopmgr, &netmgr);
isc_log_create(mctx, &lctx, &lcfg);
RUNCHECK(dst_lib_init(mctx, NULL));
@@ -2215,6 +2212,6 @@ main(int argc, char *argv[]) {
isc_mem_free(mctx, default_query.ecs_addr);
}
- isc_managers_destroy(&mctx, &loopmgr, &netmgr, &taskmgr);
+ isc_managers_destroy(&mctx, &loopmgr, &netmgr);
return (0);
}
diff --git a/doc/arm/reference.rst b/doc/arm/reference.rst
index 97459524037..4a159e72efb 100644
--- a/doc/arm/reference.rst
+++ b/doc/arm/reference.rst
@@ -5756,7 +5756,6 @@ reconfiguration time), http://127.0.0.1:8888/xml/v3/server (server and
resolver statistics), http://127.0.0.1:8888/xml/v3/zones (zone
statistics), http://127.0.0.1:8888/xml/v3/net (network status and socket
statistics), http://127.0.0.1:8888/xml/v3/mem (memory manager
-statistics), http://127.0.0.1:8888/xml/v3/tasks (task manager
statistics), and http://127.0.0.1:8888/xml/v3/traffic (traffic sizes).
The full set of statistics can also be read in JSON format at
@@ -5766,7 +5765,6 @@ reconfiguration time), http://127.0.0.1:8888/json/v1/server (server and
resolver statistics), http://127.0.0.1:8888/json/v1/zones (zone
statistics), http://127.0.0.1:8888/json/v1/net (network status and
socket statistics), http://127.0.0.1:8888/json/v1/mem (memory manager
-statistics), http://127.0.0.1:8888/json/v1/tasks (task manager
statistics), and http://127.0.0.1:8888/json/v1/traffic (traffic sizes).
:any:`tls` Block Grammar
diff --git a/lib/dns/Makefile.am b/lib/dns/Makefile.am
index 4f657192aba..c15de0d57a1 100644
--- a/lib/dns/Makefile.am
+++ b/lib/dns/Makefile.am
@@ -73,7 +73,6 @@ libdns_la_HEADERS = \
include/dns/dyndb.h \
include/dns/ecs.h \
include/dns/edns.h \
- include/dns/events.h \
include/dns/fixedname.h \
include/dns/forward.h \
include/dns/geoip.h \
diff --git a/lib/dns/adb.c b/lib/dns/adb.c
index 02e713df1c6..df88cbd5b11 100644
--- a/lib/dns/adb.c
+++ b/lib/dns/adb.c
@@ -29,13 +29,11 @@
#include
#include
#include
-#include
#include
#include
#include
#include
-#include
#include
#include
#include
@@ -379,6 +377,8 @@ destroy(dns_adb_t *);
static void
shutdown_names(dns_adb_t *);
static void
+shutdown_entries(dns_adb_t *);
+static void
water(void *, int);
static void
dump_entry(FILE *, dns_adb_t *, dns_adbentry_t *, bool, isc_stdtime_t);
diff --git a/lib/dns/byaddr.c b/lib/dns/byaddr.c
index b4d7b79b37d..df53ebdab4c 100644
--- a/lib/dns/byaddr.c
+++ b/lib/dns/byaddr.c
@@ -19,12 +19,10 @@
#include
#include
#include
-#include
#include
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/catz.c b/lib/dns/catz.c
index 2f1b900b921..1b5b8c2029a 100644
--- a/lib/dns/catz.c
+++ b/lib/dns/catz.c
@@ -27,7 +27,6 @@
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/client.c b/lib/dns/client.c
index 72588ce0e63..c6f94acab54 100644
--- a/lib/dns/client.c
+++ b/lib/dns/client.c
@@ -31,7 +31,6 @@
#include
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/dnstap.c b/lib/dns/dnstap.c
index 52115520dc1..6e8f8319254 100644
--- a/lib/dns/dnstap.c
+++ b/lib/dns/dnstap.c
@@ -69,7 +69,6 @@
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/include/dns/byaddr.h b/lib/dns/include/dns/byaddr.h
index 4c18ddad282..718221f084a 100644
--- a/lib/dns/include/dns/byaddr.h
+++ b/lib/dns/include/dns/byaddr.h
@@ -40,7 +40,6 @@
*\li Drafts: TBS
*/
-#include
#include
#include
diff --git a/lib/dns/include/dns/client.h b/lib/dns/include/dns/client.h
index 3bfde55f00a..166822433ba 100644
--- a/lib/dns/include/dns/client.h
+++ b/lib/dns/include/dns/client.h
@@ -39,7 +39,6 @@
* security issue specific to this module is anticipated.
*/
-#include
#include
#include
#include
diff --git a/lib/dns/include/dns/dyndb.h b/lib/dns/include/dns/dyndb.h
index f3020b87f57..82026d154eb 100644
--- a/lib/dns/include/dns/dyndb.h
+++ b/lib/dns/include/dns/dyndb.h
@@ -55,7 +55,7 @@ struct dns_dyndbctx {
* if not, set DNS_DYNDB_AGE to 0.
*/
#ifndef DNS_DYNDB_VERSION
-#define DNS_DYNDB_VERSION 1
+#define DNS_DYNDB_VERSION 2
#define DNS_DYNDB_AGE 0
#endif /* ifndef DNS_DYNDB_VERSION */
diff --git a/lib/dns/include/dns/events.h b/lib/dns/include/dns/events.h
deleted file mode 100644
index 19655aa5815..00000000000
--- a/lib/dns/include/dns/events.h
+++ /dev/null
@@ -1,85 +0,0 @@
-/*
- * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
- *
- * SPDX-License-Identifier: MPL-2.0
- *
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
- *
- * See the COPYRIGHT file distributed with this work for additional
- * information regarding copyright ownership.
- */
-
-#pragma once
-
-#include
-
-/*! \file dns/events.h
- * \brief
- * Registry of DNS event numbers.
- */
-
-#define DNS_EVENT_FETCHCONTROL (ISC_EVENTCLASS_DNS + 0)
-#define DNS_EVENT_FETCHDONE (ISC_EVENTCLASS_DNS + 1)
-/* #define DNS_EVENT_VIEWRESSHUTDOWN (ISC_EVENTCLASS_DNS + 2) */
-/* #define DNS_EVENT_VIEWADBSHUTDOWN (ISC_EVENTCLASS_DNS + 3) */
-#define DNS_EVENT_UPDATE (ISC_EVENTCLASS_DNS + 4)
-#define DNS_EVENT_UPDATEDONE (ISC_EVENTCLASS_DNS + 5)
-#define DNS_EVENT_DISPATCH (ISC_EVENTCLASS_DNS + 6)
-#define DNS_EVENT_TCPMSG (ISC_EVENTCLASS_DNS + 7)
-#define DNS_EVENT_ADBMOREADDRESSES (ISC_EVENTCLASS_DNS + 8)
-#define DNS_EVENT_ADBNOMOREADDRESSES (ISC_EVENTCLASS_DNS + 9)
-#define DNS_EVENT_ADBCANCELED (ISC_EVENTCLASS_DNS + 10)
-#define DNS_EVENT_ADBNAMEDELETED (ISC_EVENTCLASS_DNS + 11)
-#define DNS_EVENT_ADBSHUTDOWN (ISC_EVENTCLASS_DNS + 12)
-#define DNS_EVENT_ADBEXPIRED (ISC_EVENTCLASS_DNS + 13)
-#define DNS_EVENT_ADBCONTROL (ISC_EVENTCLASS_DNS + 14)
-#define DNS_EVENT_CACHECLEAN (ISC_EVENTCLASS_DNS + 15)
-#define DNS_EVENT_BYADDRDONE (ISC_EVENTCLASS_DNS + 16)
-#define DNS_EVENT_ZONECONTROL (ISC_EVENTCLASS_DNS + 17)
-#define DNS_EVENT_DBDESTROYED (ISC_EVENTCLASS_DNS + 18)
-#define DNS_EVENT_VALIDATORDONE (ISC_EVENTCLASS_DNS + 19)
-#define DNS_EVENT_REQUESTDONE (ISC_EVENTCLASS_DNS + 20)
-#define DNS_EVENT_VALIDATORSTART (ISC_EVENTCLASS_DNS + 21)
-/* #define DNS_EVENT_VIEWREQSHUTDOWN (ISC_EVENTCLASS_DNS + 22) */
-#define DNS_EVENT_NOTIFYSENDTOADDR (ISC_EVENTCLASS_DNS + 23)
-#define DNS_EVENT_ZONE (ISC_EVENTCLASS_DNS + 24)
-#define DNS_EVENT_ZONESTARTXFRIN (ISC_EVENTCLASS_DNS + 25)
-/* #define DNS_EVENT_MASTERQUANTUM (ISC_EVENTCLASS_DNS + 26) */
-#define DNS_EVENT_CACHEOVERMEM (ISC_EVENTCLASS_DNS + 27)
-#define DNS_EVENT_MASTERNEXTZONE (ISC_EVENTCLASS_DNS + 28)
-#define DNS_EVENT_IOREADY (ISC_EVENTCLASS_DNS + 29)
-#define DNS_EVENT_LOOKUPDONE (ISC_EVENTCLASS_DNS + 30)
-#define DNS_EVENT_RBTDEADNODES (ISC_EVENTCLASS_DNS + 31)
-#define DNS_EVENT_DISPATCHCONTROL (ISC_EVENTCLASS_DNS + 32)
-#define DNS_EVENT_REQUESTCONTROL (ISC_EVENTCLASS_DNS + 33)
-#define DNS_EVENT_DUMPQUANTUM (ISC_EVENTCLASS_DNS + 34)
-/* #define DNS_EVENT_IMPORTRECVDONE (ISC_EVENTCLASS_DNS + 35) */
-#define DNS_EVENT_FREESTORAGE (ISC_EVENTCLASS_DNS + 36)
-/* #define DNS_EVENT_VIEWACACHESHUTDOWN (ISC_EVENTCLASS_DNS + 37) */
-#define DNS_EVENT_ACACHECONTROL (ISC_EVENTCLASS_DNS + 38)
-#define DNS_EVENT_ACACHECLEAN (ISC_EVENTCLASS_DNS + 39)
-#define DNS_EVENT_ACACHEOVERMEM (ISC_EVENTCLASS_DNS + 40)
-#define DNS_EVENT_RBTPRUNE (ISC_EVENTCLASS_DNS + 41)
-#define DNS_EVENT_MANAGEKEYS (ISC_EVENTCLASS_DNS + 42)
-#define DNS_EVENT_CLIENTRESDONE (ISC_EVENTCLASS_DNS + 43)
-#define DNS_EVENT_CLIENTREQDONE (ISC_EVENTCLASS_DNS + 44)
-#define DNS_EVENT_ADBGROWENTRIES (ISC_EVENTCLASS_DNS + 45)
-#define DNS_EVENT_ADBGROWNAMES (ISC_EVENTCLASS_DNS + 46)
-#define DNS_EVENT_ZONESECURESERIAL (ISC_EVENTCLASS_DNS + 47)
-#define DNS_EVENT_ZONESECUREDB (ISC_EVENTCLASS_DNS + 48)
-/* #define DNS_EVENT_ZONELOAD (ISC_EVENTCLASS_DNS + 49) */
-#define DNS_EVENT_KEYDONE (ISC_EVENTCLASS_DNS + 50)
-#define DNS_EVENT_SETNSEC3PARAM (ISC_EVENTCLASS_DNS + 51)
-#define DNS_EVENT_SETSERIAL (ISC_EVENTCLASS_DNS + 52)
-#define DNS_EVENT_CATZUPDATED (ISC_EVENTCLASS_DNS + 53)
-#define DNS_EVENT_CATZADDZONE (ISC_EVENTCLASS_DNS + 54)
-#define DNS_EVENT_CATZMODZONE (ISC_EVENTCLASS_DNS + 55)
-#define DNS_EVENT_CATZDELZONE (ISC_EVENTCLASS_DNS + 56)
-#define DNS_EVENT_RPZUPDATED (ISC_EVENTCLASS_DNS + 57)
-#define DNS_EVENT_STARTUPDATE (ISC_EVENTCLASS_DNS + 58)
-#define DNS_EVENT_TRYSTALE (ISC_EVENTCLASS_DNS + 59)
-#define DNS_EVENT_ZONEFLUSH (ISC_EVENTCLASS_DNS + 60)
-#define DNS_EVENT_CHECKDSSENDTOADDR (ISC_EVENTCLASS_DNS + 61)
-#define DNS_EVENT_CACHESHUTDOWN (ISC_EVENTCLASS_DNS + 62)
diff --git a/lib/dns/include/dns/request.h b/lib/dns/include/dns/request.h
index e6213514edc..e33119742b6 100644
--- a/lib/dns/include/dns/request.h
+++ b/lib/dns/include/dns/request.h
@@ -36,7 +36,6 @@
#include
-#include
#include
#include
diff --git a/lib/dns/include/dns/rpz.h b/lib/dns/include/dns/rpz.h
index a11dd1c63af..d28d6e14b93 100644
--- a/lib/dns/include/dns/rpz.h
+++ b/lib/dns/include/dns/rpz.h
@@ -21,7 +21,6 @@
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/include/dns/validator.h b/lib/dns/include/dns/validator.h
index 704b8307992..c00e60bf78a 100644
--- a/lib/dns/include/dns/validator.h
+++ b/lib/dns/include/dns/validator.h
@@ -48,7 +48,6 @@
#include
-#include
#include
#include
diff --git a/lib/dns/include/dns/view.h b/lib/dns/include/dns/view.h
index f315def13cf..30d1a174da0 100644
--- a/lib/dns/include/dns/view.h
+++ b/lib/dns/include/dns/view.h
@@ -57,7 +57,6 @@
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/include/dns/zone.h b/lib/dns/include/dns/zone.h
index e7a162d3b4b..4969c910854 100644
--- a/lib/dns/include/dns/zone.h
+++ b/lib/dns/include/dns/zone.h
@@ -480,7 +480,7 @@ dns_zone_iattach(dns_zone_t *source, dns_zone_t **target);
* object from being freed but not from shutting down.
*
* Require:
- *\li The caller is running in the context of the zone's task.
+ *\li The caller is running in the context of the zone's loop.
*\li 'zone' to be a valid zone.
*\li 'target' to be non NULL and '*target' to be NULL.
*/
@@ -493,7 +493,7 @@ dns_zone_idetach(dns_zone_t **zonep);
* zone, it will be freed.
*
* Require:
- *\li The caller is running in the context of the zone's task.
+ *\li The caller is running in the context of the zone's loop.
*\li 'zonep' to point to a valid zone.
*/
@@ -1587,16 +1587,14 @@ dns_zone_getdnsseckeys(dns_zone_t *zone, dns_db_t *db, dns_dbversion_t *ver,
*\li Error
*/
-isc_result_t
-dns_zonemgr_create(isc_mem_t *mctx, isc_loopmgr_t *loopmgr,
- isc_taskmgr_t *taskmgr, isc_nm_t *netmgr,
+void
+dns_zonemgr_create(isc_mem_t *mctx, isc_loopmgr_t *loopmgr, isc_nm_t *netmgr,
dns_zonemgr_t **zmgrp);
/*%<
* Create a zone manager.
*
* Requires:
*\li 'mctx' to be a valid memory context.
- *\li 'taskmgr' to be a valid task manager.
*\li 'zmgrp' to point to a NULL pointer.
*/
@@ -1681,12 +1679,6 @@ dns_zonemgr_releasezone(dns_zonemgr_t *zmgr, dns_zone_t *zone);
*\li 'zone->zmgr' == NULL;
*/
-isc_taskmgr_t *
-dns_zonemgr_gettaskmgr(dns_zonemgr_t *zmgr);
-/*%
- * Get the tasmkgr object attached to 'zmgr'.
- */
-
void
dns_zonemgr_settransfersin(dns_zonemgr_t *zmgr, uint32_t value);
/*%<
diff --git a/lib/dns/include/dns/zt.h b/lib/dns/include/dns/zt.h
index 037d0a9495b..afe13ead858 100644
--- a/lib/dns/include/dns/zt.h
+++ b/lib/dns/include/dns/zt.h
@@ -34,8 +34,7 @@ typedef isc_result_t (*dns_zt_allloaded_t)(void *arg);
* this signature.
*/
-typedef isc_result_t (*dns_zt_zoneloaded_t)(dns_zt_t *zt, dns_zone_t *zone,
- isc_task_t *task);
+typedef isc_result_t (*dns_zt_zoneloaded_t)(dns_zt_t *zt, dns_zone_t *zone);
/*%<
* Method prototype: when a zone finishes loading, the zt object
* can be informed via a callback function with this signature.
diff --git a/lib/dns/master.c b/lib/dns/master.c
index 4808002d2e4..6df8fc298d9 100644
--- a/lib/dns/master.c
+++ b/lib/dns/master.c
@@ -18,7 +18,6 @@
#include
#include
-#include
#include
#include
#include
@@ -33,7 +32,6 @@
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/masterdump.c b/lib/dns/masterdump.c
index c3c1d5428b5..728b1d3dde5 100644
--- a/lib/dns/masterdump.c
+++ b/lib/dns/masterdump.c
@@ -20,7 +20,6 @@
#include
#include
#include
-#include
#include
#include
#include
@@ -36,7 +35,6 @@
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/nta.c b/lib/dns/nta.c
index 5096ce658a4..0b44f643395 100644
--- a/lib/dns/nta.c
+++ b/lib/dns/nta.c
@@ -18,14 +18,12 @@
#include
#include
-#include
#include
#include
#include
#include
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/rpz.c b/lib/dns/rpz.c
index bcb0b222bdf..92ab5980d39 100644
--- a/lib/dns/rpz.c
+++ b/lib/dns/rpz.c
@@ -28,14 +28,12 @@
#include
#include
#include
-#include
#include
#include
#include
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/update.c b/lib/dns/update.c
index 9f1c66279ea..d3899e8e511 100644
--- a/lib/dns/update.c
+++ b/lib/dns/update.c
@@ -32,7 +32,6 @@
#include
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/validator.c b/lib/dns/validator.c
index 53b35c1e8db..baffeb3b9c0 100644
--- a/lib/dns/validator.c
+++ b/lib/dns/validator.c
@@ -26,7 +26,6 @@
#include
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/view.c b/lib/dns/view.c
index cc5315e96d3..35ce0d824b3 100644
--- a/lib/dns/view.c
+++ b/lib/dns/view.c
@@ -29,7 +29,6 @@
#include
#include
#include
-#include
#include
#include
@@ -41,7 +40,6 @@
#include
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/xfrin.c b/lib/dns/xfrin.c
index 8115cbb7172..05e505b188f 100644
--- a/lib/dns/xfrin.c
+++ b/lib/dns/xfrin.c
@@ -27,7 +27,6 @@
#include
#include
#include
-#include
#include
#include
#include
diff --git a/lib/dns/zt.c b/lib/dns/zt.c
index da4eac74ce5..48713d207f9 100644
--- a/lib/dns/zt.c
+++ b/lib/dns/zt.c
@@ -22,7 +22,6 @@
#include
#include
#include
-#include
#include
#include
@@ -78,7 +77,7 @@ static isc_result_t
freezezones(dns_zone_t *zone, void *uap);
static isc_result_t
-doneloading(dns_zt_t *zt, dns_zone_t *zone, isc_task_t *task);
+doneloading(dns_zt_t *zt, dns_zone_t *zone);
isc_result_t
dns_zt_create(isc_mem_t *mctx, dns_rdataclass_t rdclass, dns_zt_t **ztp) {
@@ -585,12 +584,11 @@ cleanup:
* dns_zt_asyncload().
*/
static isc_result_t
-doneloading(dns_zt_t *zt, dns_zone_t *zone, isc_task_t *task) {
- UNUSED(zone);
- UNUSED(task);
-
+doneloading(dns_zt_t *zt, dns_zone_t *zone) {
REQUIRE(VALID_ZT(zt));
+ UNUSED(zone);
+
if (isc_refcount_decrement(&zt->loads_pending) == 1) {
call_loaddone(zt);
}
diff --git a/lib/isc/Makefile.am b/lib/isc/Makefile.am
index 55eac3a7c98..dff12e76c9e 100644
--- a/lib/isc/Makefile.am
+++ b/lib/isc/Makefile.am
@@ -27,8 +27,6 @@ libisc_la_HEADERS = \
include/isc/entropy.h \
include/isc/errno.h \
include/isc/error.h \
- include/isc/event.h \
- include/isc/eventclass.h \
include/isc/file.h \
include/isc/formatcheck.h \
include/isc/fsaccess.h \
@@ -87,7 +85,6 @@ libisc_la_HEADERS = \
include/isc/string.h \
include/isc/symtab.h \
include/isc/syslog.h \
- include/isc/task.h \
include/isc/thread.h \
include/isc/tid.h \
include/isc/time.h \
@@ -129,7 +126,6 @@ libisc_la_SOURCES = \
errno2result.c \
errno2result.h \
error.c \
- event.c \
file.c \
fsaccess.c \
fsaccess_common.c \
@@ -191,7 +187,6 @@ libisc_la_SOURCES = \
string.c \
symtab.c \
syslog.c \
- task.c \
thread.c \
tid.c \
time.c \
diff --git a/lib/isc/event.c b/lib/isc/event.c
deleted file mode 100644
index cf5bdee5583..00000000000
--- a/lib/isc/event.c
+++ /dev/null
@@ -1,65 +0,0 @@
-/*
- * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
- *
- * SPDX-License-Identifier: MPL-2.0
- *
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
- *
- * See the COPYRIGHT file distributed with this work for additional
- * information regarding copyright ownership.
- */
-
-/*!
- * \file
- */
-
-#include
diff --git a/lib/dns/zone.c b/lib/dns/zone.c
index 48b9221dffb..36cdfe3619b 100644
--- a/lib/dns/zone.c
+++ b/lib/dns/zone.c
@@ -36,7 +36,6 @@
#include
#include
#include
-#include
#include
#include
#include
@@ -51,7 +50,6 @@
#include
#include
#include
-#include
#include
#include
#include
@@ -318,9 +316,6 @@ struct dns_zone {
dns_remote_t notify;
dns_notifytype_t notifytype;
isc_sockaddr_t notifyfrom;
-
- isc_task_t *task;
-
isc_sockaddr_t notifysrc4;
isc_sockaddr_t notifysrc6;
isc_sockaddr_t parentalsrc4;
@@ -328,8 +323,7 @@ struct dns_zone {
isc_sockaddr_t xfrsource4;
isc_sockaddr_t xfrsource6;
isc_sockaddr_t sourceaddr;
-
- dns_xfrin_ctx_t *xfr; /* task locked */
+ dns_xfrin_ctx_t *xfr; /* loop locked */
dns_tsigkey_t *tsigkey; /* key used for xfr */
dns_transport_t *transport; /* transport used for xfr */
/* Access Control Lists */
@@ -592,10 +586,8 @@ struct dns_zonemgr {
isc_mem_t *mctx;
isc_refcount_t refs;
isc_loopmgr_t *loopmgr;
- isc_taskmgr_t *taskmgr;
isc_nm_t *netmgr;
uint32_t workers;
- isc_task_t **zonetasks;
isc_mem_t **mctxpool;
isc_ratelimiter_t *checkdsrl;
isc_ratelimiter_t *notifyrl;
@@ -1189,10 +1181,6 @@ zone_free(dns_zone_t *zone) {
INSIST(zone->view == NULL);
INSIST(zone->prev_view == NULL);
- if (zone->task != NULL) {
- isc_task_detach(&zone->task);
- }
-
/* Unmanaged objects */
for (struct np3 *npe = ISC_LIST_HEAD(zone->setnsec3param_queue);
npe != NULL; npe = ISC_LIST_HEAD(zone->setnsec3param_queue))
@@ -2247,7 +2235,7 @@ zone_load(dns_zone_t *zone, unsigned int flags, bool locked) {
"no master file");
}
zone->refreshtime = now;
- if (zone->task != NULL) {
+ if (zone->loop != NULL) {
zone_settimer(zone, &now);
}
result = ISC_R_SUCCESS;
@@ -2351,7 +2339,7 @@ zone_asyncload(void *arg) {
/* Inform the zone table we've finished loading */
if (asl->loaded != NULL) {
- (asl->loaded)(asl->loaded_arg, zone, zone->task);
+ (asl->loaded)(asl->loaded_arg, zone);
}
isc_mem_put(zone->mctx, asl, sizeof(*asl));
@@ -3657,7 +3645,7 @@ zone_addnsec3chain(dns_zone_t *zone, dns_rdata_nsec3param_t *nsec3param) {
if (isc_time_isepoch(&zone->nsec3chaintime)) {
TIME_NOW(&now);
zone->nsec3chaintime = now;
- if (zone->task != NULL) {
+ if (zone->loop != NULL) {
zone_settimer(zone, &now);
}
}
@@ -5144,7 +5132,7 @@ zone_postload(dns_zone_t *zone, dns_db_t *db, isc_time_t loadtime,
}
}
- if (zone->task != NULL) {
+ if (zone->loop != NULL) {
if (zone->type == dns_zone_primary) {
set_resigntime(zone);
resume_signingwithkey(zone);
@@ -5260,7 +5248,7 @@ cleanup:
/* Mark the zone for immediate refresh. */
zone->refreshtime = now;
- if (zone->task != NULL) {
+ if (zone->loop != NULL) {
zone_settimer(zone, &now);
}
result = ISC_R_SUCCESS;
@@ -5295,7 +5283,7 @@ done:
* due to DNS_ZONEFLG_LOADPENDING being set when
* zone_maintenance was called.
*/
- if (zone->secure->task != NULL) {
+ if (zone->secure->loop != NULL) {
zone_settimer(zone->secure, &now);
}
}
@@ -11000,7 +10988,7 @@ zone_maintenance(dns_zone_t *zone) {
}
UNLOCK_ZONE(zone);
if (!dumping) {
- result = zone_dump(zone, true); /* task locked */
+ result = zone_dump(zone, true); /* loop locked */
if (result != ISC_R_SUCCESS) {
dns_zone_log(zone, ISC_LOG_WARNING,
"dump failed: %s",
@@ -11156,7 +11144,7 @@ again:
/* XXXMPA make separate call back */
if (result == ISC_R_SUCCESS) {
set_resigntime(zone);
- if (zone->task != NULL) {
+ if (zone->loop != NULL) {
isc_time_t now;
TIME_NOW(&now);
zone_settimer(zone, &now);
@@ -11442,7 +11430,7 @@ dns_zone_flush(dns_zone_t *zone) {
}
UNLOCK_ZONE(zone);
if (!dumping) {
- result = zone_dump(zone, true); /* Unknown task. */
+ result = zone_dump(zone, true);
}
return (result);
}
@@ -11458,7 +11446,7 @@ dns_zone_dump(dns_zone_t *zone) {
dumping = was_dumping(zone);
UNLOCK_ZONE(zone);
if (!dumping) {
- result = zone_dump(zone, false); /* Unknown task. */
+ result = zone_dump(zone, false);
}
return (result);
}
@@ -11495,7 +11483,7 @@ zone_needdump(dns_zone_t *zone, unsigned int delay) {
{
zone->dumptime = dumptime;
}
- if (zone->task != NULL) {
+ if (zone->loop != NULL) {
zone_settimer(zone, &now);
}
}
@@ -11636,7 +11624,7 @@ zone_dump(dns_zone_t *zone, bool compact) {
dns_masterrawheader_t rawdata;
/*
* 'compact' MUST only be set if we are task locked.
*/
REQUIRE(DNS_ZONE_VALID(zone));
@@ -14488,7 +14476,7 @@ zone_shutdown(void *arg) {
}
/*
* In task context, no locking required. See zone_xfrdone().
*/
if (zone->xfr != NULL) {
/* The final detach will happen in zone_xfrdone() */
@@ -17354,7 +17342,7 @@ dns_zone_setsigresigninginterval(dns_zone_t *zone, uint32_t interval) {
LOCK_ZONE(zone);
zone->sigresigninginterval = interval;
set_resigntime(zone);
- if (zone->task != NULL) {
+ if (zone->loop != NULL) {
TIME_NOW(&now);
zone_settimer(zone, &now);
}
@@ -17999,17 +17987,14 @@ zonemgr_keymgmt_delete(dns_zonemgr_t *zmgr, dns_keyfileio_t **deleted) {
RWUNLOCK(&mgmt->lock, isc_rwlocktype_write);
}
-isc_result_t
-dns_zonemgr_create(isc_mem_t *mctx, isc_loopmgr_t *loopmgr,
- isc_taskmgr_t *taskmgr, isc_nm_t *netmgr,
+void
+dns_zonemgr_create(isc_mem_t *mctx, isc_loopmgr_t *loopmgr, isc_nm_t *netmgr,
dns_zonemgr_t **zmgrp) {
- dns_zonemgr_t *zmgr;
- isc_result_t result;
+ dns_zonemgr_t *zmgr = NULL;
isc_loop_t *loop = isc_loop_current(loopmgr);
REQUIRE(mctx != NULL);
REQUIRE(loopmgr != NULL);
- REQUIRE(taskmgr != NULL);
REQUIRE(netmgr != NULL);
REQUIRE(zmgrp != NULL && *zmgrp == NULL);
@@ -18017,7 +18002,6 @@ dns_zonemgr_create(isc_mem_t *mctx, isc_loopmgr_t *loopmgr,
*zmgr = (dns_zonemgr_t){
.loopmgr = loopmgr,
- .taskmgr = taskmgr,
.netmgr = netmgr,
.workers = isc_loopmgr_nloops(loopmgr),
.transfersin = 10,
@@ -18045,17 +18029,6 @@ dns_zonemgr_create(isc_mem_t *mctx, isc_loopmgr_t *loopmgr,
isc_ratelimiter_create(loop, &zmgr->startupnotifyrl);
isc_ratelimiter_create(loop, &zmgr->startuprefreshrl);
- zmgr->zonetasks = isc_mem_getx(
- zmgr->mctx, zmgr->workers * sizeof(zmgr->zonetasks[0]),
- ISC_MEM_ZERO);
- for (size_t i = 0; i < zmgr->workers; i++) {
- result = isc_task_create(zmgr->taskmgr, &zmgr->zonetasks[i], i);
- if (result != ISC_R_SUCCESS) {
- goto free_zonetasks;
- }
- isc_task_setname(zmgr->zonetasks[i], "zonemgr-zonetasks", NULL);
- }
-
zmgr->mctxpool = isc_mem_getx(zmgr->mctx,
zmgr->workers * sizeof(zmgr->mctxpool[0]),
ISC_MEM_ZERO);
@@ -18081,38 +18054,6 @@ dns_zonemgr_create(isc_mem_t *mctx, isc_loopmgr_t *loopmgr,
zmgr->magic = ZONEMGR_MAGIC;
*zmgrp = zmgr;
- return (ISC_R_SUCCESS);
-
-#if 0
- free_iolock:
- isc_mutex_destroy(&zmgr->iolock);
-#endif /* if 0 */
-
-free_zonetasks:
- for (size_t i = 0; i < zmgr->workers; i++) {
- if (zmgr->zonetasks[i] != NULL) {
- isc_task_detach(&zmgr->zonetasks[i]);
- }
- }
- isc_mem_put(zmgr->mctx, zmgr->zonetasks,
- zmgr->workers * sizeof(zmgr->zonetasks[0]));
-
- isc_ratelimiter_shutdown(zmgr->startuprefreshrl);
- isc_ratelimiter_detach(&zmgr->startuprefreshrl);
- isc_ratelimiter_shutdown(zmgr->startupnotifyrl);
- isc_ratelimiter_detach(&zmgr->startupnotifyrl);
- isc_ratelimiter_shutdown(zmgr->refreshrl);
- isc_ratelimiter_detach(&zmgr->refreshrl);
- isc_ratelimiter_shutdown(zmgr->notifyrl);
- isc_ratelimiter_detach(&zmgr->notifyrl);
- isc_ratelimiter_shutdown(zmgr->checkdsrl);
- isc_ratelimiter_detach(&zmgr->checkdsrl);
-
- isc_rwlock_destroy(&zmgr->urlock);
- isc_rwlock_destroy(&zmgr->rwlock);
- isc_mem_put(zmgr->mctx, zmgr, sizeof(*zmgr));
- isc_mem_detach(&mctx);
- return (result);
}
isc_result_t
@@ -18150,25 +18091,11 @@ dns_zonemgr_managezone(dns_zonemgr_t *zmgr, dns_zone_t *zone) {
REQUIRE(DNS_ZONE_VALID(zone));
REQUIRE(DNS_ZONEMGR_VALID(zmgr));
- if (zmgr->zonetasks == NULL) {
- return (ISC_R_FAILURE);
- }
-
RWLOCK(&zmgr->rwlock, isc_rwlocktype_write);
LOCK_ZONE(zone);
- REQUIRE(zone->task == NULL);
REQUIRE(zone->timer == NULL);
REQUIRE(zone->zmgr == NULL);
- isc_task_attach(zmgr->zonetasks[zone->tid], &zone->task);
-
- /*
- * Set the task name. The tag will arbitrarily point to one
- * of the zones sharing the task (in practice, the one
- * to be managed last).
- */
- isc_task_setname(zone->task, "zone", zone);
-
zone->loop = isc_loop_get(zmgr->loopmgr, zone->tid);
zonemgr_keymgmt_add(zmgr, zone, &zone->kfio);
@@ -18287,10 +18214,6 @@ dns_zonemgr_shutdown(dns_zonemgr_t *zmgr) {
isc_mem_detach(&zmgr->mctxpool[i]);
}
- for (size_t i = 0; i < zmgr->workers; i++) {
- isc_task_detach(&zmgr->zonetasks[i]);
- }
-
RWLOCK(&zmgr->rwlock, isc_rwlocktype_read);
for (zone = ISC_LIST_HEAD(zmgr->zones); zone != NULL;
zone = ISC_LIST_NEXT(zone, link))
@@ -18317,8 +18240,6 @@ zonemgr_free(dns_zonemgr_t *zmgr) {
isc_mem_put(zmgr->mctx, zmgr->mctxpool,
zmgr->workers * sizeof(zmgr->mctxpool[0]));
- isc_mem_put(zmgr->mctx, zmgr->zonetasks,
- zmgr->workers * sizeof(zmgr->zonetasks[0]));
isc_rwlock_destroy(&zmgr->urlock);
isc_rwlock_destroy(&zmgr->rwlock);
@@ -18359,13 +18280,6 @@ dns_zonemgr_gettransfersperns(dns_zonemgr_t *zmgr) {
return (zmgr->transfersperns);
}
-isc_taskmgr_t *
-dns_zonemgr_gettaskmgr(dns_zonemgr_t *zmgr) {
- REQUIRE(DNS_ZONEMGR_VALID(zmgr));
-
- return (zmgr->taskmgr);
-}
-
/*
* Try to start a new incoming zone transfer to fill a quota
* slot that was just vacated.
@@ -18434,7 +18348,7 @@ zmgr_start_xfrin_ifquota(dns_zonemgr_t *zmgr, dns_zone_t *zone) {
/*
* If we are exiting just pretend we got quota so the zone will
* be cleaned up in the zone's task context.
*/
LOCK_ZONE(zone);
if (DNS_ZONE_FLAG(zone, DNS_ZONEFLG_EXITING)) {
@@ -19271,7 +19185,7 @@ zone_signwithkey(dns_zone_t *zone, dns_secalg_t algorithm, uint16_t keyid,
signing = NULL;
if (isc_time_isepoch(&zone->signingtime)) {
zone->signingtime = now;
- if (zone->task != NULL) {
+ if (zone->loop != NULL) {
zone_settimer(zone, &now);
}
}
@@ -21039,7 +20953,7 @@ void
dns_zone_rekey(dns_zone_t *zone, bool fullsign) {
isc_time_t now;
- if (zone->type == dns_zone_primary && zone->task != NULL) {
+ if (zone->type == dns_zone_primary && zone->loop != NULL) {
LOCK_ZONE(zone);
if (fullsign) {
@@ -21418,12 +21332,12 @@ dns_zone_link(dns_zone_t *zone, dns_zone_t *raw) {
REQUIRE(DNS_ZONE_VALID(zone));
REQUIRE(zone->zmgr != NULL);
- REQUIRE(zone->task != NULL);
+ REQUIRE(zone->loop != NULL);
REQUIRE(zone->raw == NULL);
REQUIRE(DNS_ZONE_VALID(raw));
REQUIRE(raw->zmgr == NULL);
- REQUIRE(raw->task == NULL);
+ REQUIRE(raw->loop == NULL);
REQUIRE(raw->secure == NULL);
REQUIRE(zone != raw);
@@ -21445,8 +21359,6 @@ dns_zone_link(dns_zone_t *zone, dns_zone_t *raw) {
/* dns_zone_iattach(zone, &raw->secure); */
zone_iattach(zone, &raw->secure);
- isc_task_attach(zone->task, &raw->task);
-
ISC_LIST_APPEND(zmgr->zones, raw, link);
raw->zmgr = zmgr;
isc_refcount_increment(&zmgr->refs);
@@ -21675,7 +21587,7 @@ failure:
}
/*
* Called from the zone task's queue after the relevant event is posted by
* dns_zone_setnsec3param().
*/
static void
@@ -22157,7 +22069,7 @@ failure:
* in the "data" field of the nsec3param_t structure.
*
* Once the nsec3param_t structure is prepared, post an event to the zone's
* task which will cause setnsec3param() to be called with the prepared
* structure passed as an argument.
*/
isc_result_t
@@ -11636,7 +11624,7 @@ zone_dump(dns_zone_t *zone, bool compact) {
dns_masterrawheader_t rawdata;
/*
- * 'compact' MUST only be set if we are task locked.
+ * 'compact' MUST only be set if we are loop locked.
*/
REQUIRE(DNS_ZONE_VALID(zone));
@@ -14488,7 +14476,7 @@ zone_shutdown(void *arg) {
}
/*
- * In task context, no locking required. See zone_xfrdone().
+ * In loop context, no locking required. See zone_xfrdone().
*/
if (zone->xfr != NULL) {
@@ -18434,7 +18348,7 @@ zmgr_start_xfrin_ifquota(dns_zonemgr_t *zmgr, dns_zone_t *zone) {
/*
* If we are exiting just pretend we got quota so the zone will
- * be cleaned up in the zone's task context.
+ * be cleaned up in the zone's loop context.
*/
LOCK_ZONE(zone);
@@ -21675,7 +21587,7 @@ failure:
}
/*
- * Called from the zone task's queue after the relevant event is posted by
+ * Called from the zone loop's queue after the relevant event is posted by
* dns_zone_setnsec3param().
*/
@@ -22157,7 +22069,7 @@ failure:
*
* Once the nsec3param_t structure is prepared, post an event to the zone's
- * task which will cause setnsec3param() to be called with the prepared
+ * loop which will cause setnsec3param() to be called with the prepared
* structure passed as an argument.
*/